@charset "utf-8";

/* Theme Color */
.property-block-two h3 a:hover,
.property-block-two .property-info li i,
.time-counter .time-countdown .counter-column,
.property-block-two .lucation i,
.property-block-two .tags li a,
.blog-detail .post-share-options .social-icon li a:hover,
.header-style-seven .main-menu .navigation > li:hover > a, 
.header-style-seven .main-menu .navigation > li.current > a,
.header-style-three .main-menu .navigation > li:hover > a, 
.header-style-three .main-menu .navigation > li.current > a,
.new-property h3 a:hover,
.header-style-six .main-menu .navigation > li:hover > a, 
.header-style-six .main-menu .navigation > li.current > a,
.recent-properties .post:hover h3 a,
.recent-properties .post .location,
.cat-list li.active a,
.cat-list li:hover a,
.service-block .icon-box,
.popular-posts .post h4 a:hover,
.agent-widget .social-links li a,
.agent-widget .social-links li,
.agent-widget .info-box .designation,
.main-footer .footer-bottom .footer-nav ul li a:hover,
.main-footer .list li a:hover,
.main-footer .list li:before,
.main-footer .contact-list li a:hover,
.main-footer .contact-list li span,
.social-icon-two li a:hover,
.accordion-box .block .icon,
.accordion-box .block .acc-btn.active,
.testimonial-carousel-two .owl-next:hover,
.testimonial-carousel-two .owl-prev:hover,
.testimonial-block-two .info-box .name,
.testimonial-block .content-box .rating span,
.testimonial-block .content-box .name,
.blog-detail .post-share-options .tags a:hover,
.blog-detail .lower-content .info li span,
.news-block-three .content-box h3 a:hover,
.news-block-three .content-box .info li span,
.news-block-two .content-box .info li i,
.news-block-two .content-box h4 a:hover,
.news-block .lower-content h3 a:hover,
.news-block .lower-content .info li span,
.process-block h4 a,
.feature-block-two h4 a:hover,
.feature-block-two .inner-box:hover .icon-box,
.agent-detail .contact-info .social-links li a i,
.agent-detail .contact-info ul li span,
.agent-detail .contact-info ul li a:hover,
.agent-detail .contact-info ul li i,
.agent-detail .designation,
.agent-block .info-box .name a,
.agent-block .info-box .name,
.service-block .link-box a,
.service-block h4 a:hover,
.sec-title .title,
.btn-style-six,
.popular-places-carousel .owl-next:hover,
.popular-places-carousel .owl-prev:hover,
.popular-item-two .info-box .category a:hover,
.about-us.style-two .feature-block h4 a:hover,
.feature-block h4 a:hover,
.feature-block .inner-box .icon,
.fun-facts-section .column .icon-box,
.lucation-info-box .info-box .price span,
.lucation-info-box .info-box .othre-options li a:hover,
.property-block-four .property-info li i,
.property-block-four .location i,
.property-block-four .price i,
.property-block-four h3 a:hover,
.property-block-three .property-info li i,
.property-block-three .lucation i,
.property-block-three h3 a:hover,
.property-block-three .tags li a,
.property-block-three .tags li,
.property-block-three .image-box .info li a:hover,
.property-block-three .image-box .info li i,
.sidebar-page-container .filter-options li.active a,
.sidebar-page-container .filter-options li a:hover,
.property-filter-section .mixitup-gallery .filters li.active,
.property-filter-section .mixitup-gallery .filters li:hover,
.review-area .review-box .rating a:hover,
.review-area .review-box .rating,
.review-area .review-box .date i,
.flooring-tabs .tab-buttons li:hover,
.flooring-tabs .tab-buttons li.active-btn,
.property-detail .thumbs-carousel .owl-prev:hover,
.property-detail .thumbs-carousel .owl-next:hover,
.upper-info-box .price-column .price,
.upper-info-box .property-info li i,
.upper-info-box .location i,
.property-block-two .tags li,
.property-block-two .image-box .info li a:hover,
.property-block-two .image-box .info li i,
.property-carousel .owl-next:hover,
.property-carousel .owl-prev:hover,
.new-property .property-info li i,
.new-property .lucation i,
.property-block .property-info li i,
.property-block .lucation i,
.property-block h3 a:hover,
.property-block .tags li a,
.property-block .tags li,
.property-block .image-box .info li a:hover,
.property-block .image-box .info li i,
.property-search-section-two .content-box h2 span,
.property-search-form .range-slider-one .theme-btn:hover,
.banner-carousel .content-box .price,
.banner-carousel .content-box .info-box li span,
.main-slider .info-list li span,
.page-title .bread-crumb li a,
.header-style-seven .info-box .icon-box,
.header-style-seven .top-right ul li a:hover,
.header-style-seven .top-left .text span,
.header-style-six .outer-box .social-icon-one li a:hover,
.header-style-six .outer-box .link-box a:hover,
.header-style-four .main-menu .navigation > li.current > a,
.header-style-four .main-menu .navigation > li:hover > a,
.header-style-four .main-menu .navigation > li:before,
.header-style-three .info-box .icon-box,
.header-style-three .top-right ul li a:hover,
.header-style-three .top-left .text span,
.main-menu .navigation > li.current > a,
.main-menu .navigation > li:hover > a,
.social-icon-one li a:hover,
.main-header .top-left .contact-list li a:hover,
.main-header .top-left .contact-list li i,
.scroll-to-top:hover,
.banner-section.style-two .content-box h2 span,
.sticky-header .main-menu .navigation > li:hover > a, 
.sticky-header .main-menu .navigation > li.current > a, 
.sticky-header .main-menu .navigation > li.current-menu-item > a,
.list-style-one li:before,
.btn-style-four:hover,
.btn-style-three:hover,
.theme_color,
a{
	color: #ff7e00;
}


/*=== Background Color ===*/
.property-block-two .property-price .read-more,
.header-style-one .header-lower .logo-box:before,
.recent-properties .post-thumb .status,
.contact-section .info-column,
.contact-section:after,
.faq-tabs .tab-btns .tab-btn.active-btn,
.news-block-three .image-box:hover .icon-box,
.news-block .image-box:hover .icon-box,
.styled-pagination li a:hover,
.styled-pagination li.active a,
.process-block .inner-box:hover .icon-box,
.app-section:before,
.agents-carousel .owl-next:hover,
.agents-carousel .owl-prev:hover,
.agent-block .inner-box:hover .info-box,
.popular-item-two .image-box .overlay-box:before,
.popular-item .image:before,
.play-now .icon,
.fun-facts-section .video-box .image:before,
.lucation-info-box .info-box .status,
.property-block-four .text:before,
.property-block-four .status,
.property-block-three .property-price .read-more,
.property-block-three .image-box .featured,
.property-block-three .image-box .option-box li,
.property-block-three .image-box .for,
.review-area .review-box .thumb-box .reply-btn,
.review-area .review-box .thumb-box .reply-btn,
.recent-property-section .owl-next:hover,
.recent-property-section .owl-prev:hover,
.property-block-two .image-box .featured,
.property-block-two .image-box .option-box li,
.property-block-two .image-box .for,
.new-property .text:before,
.property-block .property-price .read-more,
.property-block .image-box .featured,
.property-block .image-box .option-box li,
.property-block .image-box .for,
.banner-section.style-two .owl-next:hover, 
.banner-section.style-two .owl-prev:hover,
.property-search-form .range-slider-one .ui-slider .ui-slider-range,
.ui-state-active,
.ui-widget-content .ui-state-active, 
.ui-widget-header .ui-state-active, 
a.ui-button:active, .ui-button:active, 
.ui-button.ui-state-active:hover,
.property-search-tabs .tab-buttons .tab-btn.active-btn,
.banner-carousel .owl-dot:hover,
.banner-carousel .owl-dot.active,
.banner-carousel .content-box .status,
.sec-title:after,
.sec-title:before,
.new-property .status,
.btn-style-six:hover,
.header-style-six .main-menu .navigation > li > a:after,
.header-style-seven .header-lower .outer-box .btn-box:before,
.header-style-four .main-menu .navigation > li > a:after,
.header-style-four .main-menu .navigation > li > a:before,
.header-style-three .header-lower .main-box:before,
.header-style-one .header-lower .logo-box ,
.scroll-to-top,
.btn-style-five,
.btn-style-four,
.btn-style-one{
	background-color: #ff7e00;
}


/*Border Color*/
.agent-from-widget .form-group input:focus,
.agent-from-widget .form-group textarea:focus,
.main-footer .subscribe-form .form-group input:focus,
.contact-form .form-group input:focus,
.contact-form .form-group select:focus,
.contact-form .form-group textarea:focus,
.faq-form .form-group input:focus,
.faq-form .form-group textarea:focus,
.request-form .form-group input:focus,
.request-form .form-group select:focus,
.request-form .form-group textarea:focus,
.blog-detail blockquote,
.styled-pagination li a:hover,
.styled-pagination li.active a,
.process-block .inner-box:hover .icon-box:before,
.appointment-form .form-group input:focus,
.appointment-form .form-group textarea:focus,
.about-us .video-column .video-box:before,
.lucation-info-box .info-box .status:before,
.property-block-four .status:before,
.property-block-three .image-box .featured:before,
.review-comment-form .form-group input:focus,
.review-comment-form .form-group textarea:focus,
.property-detail blockquote,
.property-block-two .image-box .featured:before,
.property-search-form .range-slider-one .theme-btn,
.property-search-form .range-slider-one .ui-state-default,
.property-search-form .range-slider-one .ui-widget-content .ui-state-default,
.ui-state-active,
.ui-widget-content .ui-state-active, 
.ui-widget-header .ui-state-active, 
a.ui-button:active, .ui-button:active, 
.ui-button.ui-state-active:hover,
.property-search-form .form-group input:focus,
.property-search-form .form-group select:focus,
.property-search-form .form-group textarea:focus,
.property-search-section,
.login-form .form-group input[type="text"]:focus,
.login-form .form-group input[type="password"]:focus,
.login-form .form-group input[type="tel"]:focus,
.login-form .form-group input[type="email"]:focus,
.login-form .form-group select:focus,
.login-form .form-group textarea:focus,
.header-style-two .header-lower .inner-container:before,
.main-header .search-box-btn,
.main-menu .navigation > li .mega-menu-bar .column > ul > li > a:hover,
.main-menu .navigation > li > ul > li  > ul > li > a:hover,
.main-menu .navigation > li > ul > li:hover > a,
.btn-style-six{
	border-color: #ff7e00;
}

.new-property .status:before,
.header-style-one .header-lower .logo:after{
	border-left-color: #ff7e00;
}


.rtl .main-menu .navigation > li .mega-menu-bar .column > ul > li > a:hover,
.rtl .main-menu .navigation > li > ul > li > ul > li:hover > a, 
.rtl .main-menu .navigation > li > ul > li:hover > a,
.rtl .property-detail blockquote,
.rtl .header-style-one .header-lower .logo:after{
	border-right-color: #ff7e00;
}
.property-block .image-box .featured:before{
	border-top-color: #ff7e00;
}

.btn-style-two:hover{
	box-shadow: #ff7e00 0 0px 0px 40px inset;
}

@media only screen and (max-width: 767px){
	
	.main-menu .navbar-header .navbar-toggle{
		border-color:#ff7e00;
	}

	.main-menu .navbar-header .navbar-toggle,
	.main-menu .navbar-collapse > .navigation,
	.main-menu .navbar-collapse > .navigation > li > ul,
	.main-menu .navbar-collapse > .navigation > li > ul > li > ul,
	.main-menu .navbar-collapse > .navigation > li > a,
	.main-menu .navbar-collapse > .navigation > li > ul > li > a,
	.main-menu .navbar-collapse > .navigation > li > ul > li > ul > li > a,
	.main-menu .navbar-collapse > .navigation > li > a:hover,
	.main-menu .navbar-collapse > .navigation > li > a:active,
	.main-menu .navbar-collapse > .navigation > li > a:focus,
	.main-menu .navbar-collapse > .navigation > li:hover > a,
	.main-menu .navbar-collapse > .navigation > li > ul > li:hover > a,
	.main-menu .navbar-collapse > .navigation > li > ul > li > ul > li:hover > a,
	.main-menu .navigation > li .mega-menu-bar .column > ul > li > a,
	.main-menu .navigation > li .mega-menu-bar .column > ul > li > a:hover,
	.main-menu .navbar-collapse > .navigation > li.current > a,
	.main-menu .navbar-collapse > .navigation > li.current-menu-item > a{
		background-color: #ff7e00;
	}
	
}